@@ -4,6 +4,8 @@ from marshmallow import ValidationError
 from frmf.db_helper import DBHelper
 from frmf.response import abort
 
+db_helper = DBHelper()
+
 
 class Logic(object):
     """
@@ -38,20 +40,20 @@ class Logic(object):
         return True, self.schema.dump(data), 200
 
     def create(self, data, query_args, *args, **kwargs):
-        with DBHelper().commit():
+        with db_helper.auto_commit():
             data = self.validate(data)
             data = self.manager.create(data)
         return True, self.schema.dump(data), 201
 
     def update(self, pk, data, partial=False, *args, **kwargs):
 
-        with DBHelper().commit():
+        with db_helper.auto_commit():
             data = self.validate(data, partial=partial)
             data = self.manager.update(pk, data)
         return True, self.schema.dump(data), 200
 
     def delete(self, pk, *args, **kwargs):
-        with DBHelper().commit():
+        with db_helper.auto_commit():
             self.manager.delete(targets=pk)
 
         return True, None, 204
